@@ -16,9 +16,9 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $Id: macros.h 11699 2004-03-22 09:35:42Z waldi $
+ * $Id: macros.h 42767 2006-11-21 10:12:29Z cjwatson $
  */
 
 #ifndef DEBIAN_INSTALLER__MACROS_H
@@ -28,4 +28,12 @@
 #define DI_STRINGIFY_ARG(contents) #contents
 #define DI_STRLOC __FILE__ ":" DI_STRINGIFY(__LINE__)
 
+/* GCC version checking borrowed from glibc. */
+#if defined(__GNUC__) && defined(__GNUC_MINOR__)
+#  define DI_GNUC_PREREQ(maj,min) \
+        ((__GNUC__ << 16) + __GNUC_MINOR__ >= ((maj) << 16) + (min))
+#else
+#  define DI_GNUC_PREREQ(maj,min) 0
+#endif
+
 #endif
